Module patterns

Functions

analyze_base64_for_secrets
Analyze base64 strings to check if they decode to known secret patterns
analyze_character_array_for_secrets
Analyze character arrays to check if they decode to secrets
analyze_hex_for_secrets
Analyze hex strings to check if they decode to known secret patterns
analyze_url_encoded_for_secrets
Analyze URL encoded strings to check if they contain database credentials
get_all_patterns
get_all_patterns_owned
is_suspicious_base64
Check if a base64 string is suspicious enough to warrant further analysis
is_suspicious_hex
Check if a hex string is suspicious enough to warrant further analysis