Functions
- analyze_
base64_ for_ secrets - Analyze base64 strings to check if they decode to known secret patterns
- analyze_
character_ array_ for_ secrets - Analyze character arrays to check if they decode to secrets
- analyze_
hex_ for_ secrets - Analyze hex strings to check if they decode to known secret patterns
- analyze_
url_ encoded_ for_ secrets - Analyze URL encoded strings to check if they contain database credentials
- get_
all_ patterns - get_
all_ patterns_ owned - is_
suspicious_ base64 - Check if a base64 string is suspicious enough to warrant further analysis
- is_
suspicious_ hex - Check if a hex string is suspicious enough to warrant further analysis